@@ -241,16 +241,12 @@ class MarionetteTestRunner(object):
 
     def start_httpd(self):
         host = moznetwork.get_ip()
-        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        s.bind(("",0))
-        port = s.getsockname()[1]
-        s.close()
-        self.baseurl = 'http://%s:%d/' % (host, port)
-        self.logger.info('running webserver on %s' % self.baseurl)
         self.httpd = MozHttpd(host=host,
-                              port=port,
+                              port=0,
                               docroot=os.path.join(os.path.dirname(__file__), 'www'))
         self.httpd.start()
+        self.baseurl = 'http://%s:%d/' % (host, self.httpd.httpd.server_port)
+        self.logger.info('running webserver on %s' % self.baseurl)
 
     def start_marionette(self):
         assert(self.baseurl is not None)
@@ -637,9 +633,7 @@ class MarionetteTestOptions(OptionParser):
                         action='store',
                         help='absolute path to directory containing breakpad symbols, or the url of a zip file containing symbols')
 
-    def verify_usage(self):
-        options, tests = self.parse_args()
-
+    def verify_usage(self, options, tests):
         if not tests:
             print 'must specify one or more test files, manifests, or directories'
             sys.exit(1)
@@ -664,6 +658,8 @@ class MarionetteTestOptions(OptionParser):
             raise ValueError('Invalid emulator resolution format. '
                              'Should be like "480x800".')
 
+        return (options, tests)
+
 
 def startTestRunner(runner_class, options, tests):
     runner = runner_class(**vars(options))
@@ -672,8 +668,8 @@ def startTestRunner(runner_class, options, tests):
 
 def cli(runner_class=MarionetteTestRunner, parser_class=MarionetteTestOptions):
     parser = parser_class(usage='%prog [options] test_file_or_dir <test_file_or_dir> ...')
-    parser.verify_usage()
     options, tests = parser.parse_args()
+    parser.verify_usage(options, tests)
 
     runner = startTestRunner(runner_class, options, tests)
     if runner.failed > 0:
